@@ -1214,15 +1214,15 @@ def normalize_uuid_str(uuid: str) -> str:
 
         # 16-bit
         uuid1 = normalize_uuid_str("1234")
-        # uuid1 == "00001234-1000-8000-00805f9b34fb"
+        # uuid1 == "00001234-0000-1000-8000-00805f9b34fb"
 
         # 32-bit
         uuid2 = normalize_uuid_str("12345678")
-        # uuid2 == "12345678-1000-8000-00805f9b34fb"
+        # uuid2 == "12345678-0000-1000-8000-00805f9b34fb"
 
         # 128-bit
-        uuid3 = normalize_uuid_str("12345678-1234-1234-1234567890ABC")
-        # uuid3 == "12345678-1234-1234-1234567890abc"
+        uuid3 = normalize_uuid_str("12345678-0000-1234-1234-1234567890ABC")
+        # uuid3 == "12345678-0000-1234-1234-1234567890abc"
 
     .. versionadded:: 0.20
     .. versionchanged:: 0.21
@@ -1245,12 +1245,12 @@ def normalize_uuid_16(uuid: int) -> str:
     Normaizes a 16-bit integer UUID to the format used by Bleak.
 
     Returns:
-        128-bit UUID as string with the format ``"0000xxxx-1000-8000-00805f9b34fb"``.
+        128-bit UUID as string with the format ``"0000xxxx-0000-1000-8000-00805f9b34fb"``.
 
     Example::
 
         uuid = normalize_uuid_16(0x1234)
-        # uuid == "00001234-1000-8000-00805f9b34fb"
+        # uuid == "00001234-0000-1000-8000-00805f9b34fb"
 
     .. versionadded:: 0.21
     """
@@ -1262,12 +1262,12 @@ def normalize_uuid_32(uuid: int) -> str:
     Normaizes a 32-bit integer UUID to the format used by Bleak.
 
     Returns:
-        128-bit UUID as string with the format ``"xxxxxxxx-1000-8000-00805f9b34fb"``.
+        128-bit UUID as string with the format ``"xxxxxxxx-0000-1000-8000-00805f9b34fb"``.
 
     Example::
 
         uuid = normalize_uuid_32(0x12345678)
-        # uuid == "12345678-1000-8000-00805f9b34fb"
+        # uuid == "12345678-0000-1000-8000-00805f9b34fb"
 
     .. versionadded:: 0.21
     """
